@@ -1,13 +1,15 @@
 import socket, urllib3, json, time
 global debug
-global serv_conf
 
 ############################## configuration
 debug = "off"
-serv_conf = "Optimal"
-version = "v0.3.5"
+modes = "optimal,random"
+version = "v0.3.9"
 servers = "gmail.com, outlook.com, yandex.com, mail.ru"
-protected = " Protection version: v1.4"
+protected = " Protection version: v1.5"
+###################################### modes
+optimal = "gmail.com,yandex.com"
+random = "gmail.com,outlook.com,yandex.com,mail.ru"
 ############################################
 
 print("\x1B[33m                           ___ __                        .__.__   ")
@@ -34,6 +36,7 @@ class server:
         data = json.loads(request.data.decode('utf8'))
         ip = str(data["mailip"])
         port = int(data["mailport"])
+        cooldown = data["cooldown"]
         request = http.request('GET', "https://api.ipify.org/")
         my_ip = request.data.decode('utf8')
         if debug == "on":
@@ -43,6 +46,7 @@ class server:
             print("[65%] My IP: "+my_ip)
             print("[70%] Checking IP on blacklist")
         message = " ".join([str(m) for m in message])
+        time.sleep(float(cooldown))
         check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         check.connect((ip, port))
         check.sendall(bytes("free|check|ip|"+my_ip,'UTF-8')) #Checking IP for dangerousness
@@ -152,6 +156,7 @@ class tempmail:
         data = json.loads(request.data.decode('utf8'))
         ip = str(data["mailip"])
         port = int(data["mailport"])
+        cooldown = data["cooldown"]
         request = http.request('GET', "https://api.ipify.org/")
         my_ip = request.data.decode('utf8')
         if debug == "on":
@@ -160,6 +165,7 @@ class tempmail:
             print("[60%] Server IP "+ip+":"+str(port))
             print("[65%] My IP: "+my_ip)
             print("[70%] Checking IP on blacklist")
+        time.sleep(float(cooldown))
         check = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         check.connect((ip, port))
         check.sendall(bytes("free|check|ip|"+my_ip,'UTF-8')) #Checking IP for dangerousness
